@@ -48,7 +48,7 @@ NOTEBOOK_SUFFIX = '.ipynb'
 CHECKPOINT_SUFFIX = '.checkpoints'
 UNTITLED_NOTEBOOK = 'Untitled'
 UNTITLED_FILE = 'Untitled'
-UNTITLED_DIRECTORY  = 'Untitled Folder'
+UNTITLED_DIRECTORY = 'Untitled Folder'
 
 Context = namedtuple('Context', [
     'logger', 'prefix', 'region', 's3_bucket', 's3_host', 's3_auth',
@@ -114,7 +114,6 @@ class CortxJupyterSecretAccessKeyAuthentication(CortxJupyterAuthentication):
         )
 
 
-
 class CortxJupyter(ContentsManager):
 
     aws_s3_bucket = Unicode(config=True)
@@ -236,6 +235,7 @@ class CortxJupyter(ContentsManager):
             s3_auth=self.authentication.get_credentials,
             prefix=self.prefix,
             multipart_uploads=self.multipart_uploads,
+            endpoint_url=self.endpoint_url
         )
 
 
@@ -316,13 +316,14 @@ def _file_exists(context, path):
 
 @gen.coroutine
 def _exists(context, path):
-    return (yield _file_exists(context, path)) or (yield _dir_exists(context, path)) 
+    return (yield _file_exists(context, path)) or (yield _dir_exists(context, path))
 
 
 @gen.coroutine
 def _get(context, path, content, type, format):
     type_to_get = type if type is not None else (yield _type_from_path(context, path))
-    format_to_get = format if format is not None else _format_from_type_and_path(context, type_to_get, path)
+    format_to_get = format if format is not None else _format_from_type_and_path(
+        context, type_to_get, path)
     return (yield GETTERS[(type_to_get, format_to_get)](context, path, content))
 
 
@@ -350,18 +351,19 @@ def _get_any(context, path, content, type, mimetype, format, decode):
 
     file_bytes = response.Body
     last_modified_str = response.LastModified
-    last_modified = datetime.datetime.strptime(last_modified_str, "%a, %d %b %Y %H:%M:%S GMT")
+    last_modified = datetime.datetime.strptime(
+        last_modified_str, "%a, %d %b %Y %H:%M:%S GMT")
     return {
         'name': _final_path_component(path),
         'path': path,
         'type': type,
         'mimetype': mimetype,
         'writable': True,
-        'last_modified': last_modified, 
+        'last_modified': last_modified,
         'created': last_modified,
-        'format': format if content else None,  
+        'format': format if content else None,
         'content': decode(file_bytes) if content else None,
-    }  
+    }
 
 
 @gen.coroutine
@@ -380,7 +382,7 @@ def _get_directory(context, path, content):
         'type': 'directory',
         'mimetype': None,
         'writable': True,
-        'last_modified': datetime.datetime.fromtimestamp(86400), 
+        'last_modified': datetime.datetime.fromtimestamp(86400),
         'created': datetime.datetime.fromtimestamp(86400),
         'format': 'json' if content else None,
         'content': ([
@@ -407,7 +409,8 @@ def _get_directory(context, path, content):
 @gen.coroutine
 def _save(context, model, path):
     type_to_save = model['type'] if 'type' in model else (yield _type_from_path(context, path))
-    format_to_save = model['format'] if 'format' in model else _format_from_type_and_path(context, type_to_save, path)
+    format_to_save = model['format'] if 'format' in model else _format_from_type_and_path(
+        context, type_to_save, path)
     return (yield SAVERS[(type_to_save, format_to_save)](
         context,
         model['chunk'] if 'chunk' in model else None,
@@ -467,7 +470,8 @@ def _save_bytes(context, content_bytes, path, type, mimetype):
     _put_object(context.aws_s3_bucket, content_bytes, object_name)
 
     last_modified_str = response.headers['Date']
-    last_modified = datetime.datetime.strptime(last_modified_str, "%a, %d %b %Y %H:%M:%S GMT")
+    last_modified = datetime.datetime.strptime(
+        last_modified_str, "%a, %d %b %Y %H:%M:%S GMT")
     return _saved_model(path, type, mimetype, last_modified)
 
 
@@ -478,7 +482,7 @@ def _saved_model(path, type, mimetype, last_modified):
         'type': type,
         'mimetype': mimetype,
         'writable': True,
-        'last_modified': last_modified, 
+        'last_modified': last_modified,
         'created': last_modified,
         'format': None,
         'content': None,
@@ -620,6 +624,7 @@ def _delete(context, path):
 def _delete_key(context, key):
     yield _delete_object(context.aws_s3_bucket, key)
 
+
 @gen.coroutine
 def _new_untitled(context, path, type, ext):
     if not (yield _dir_exists(context, path)):
@@ -717,7 +722,7 @@ def _list_keys(context, key_prefix, delimeter):
     def _list_first_page():
 
         response = yield _list_objects(context.aws_s3_bucket, key_prefix, delimiter, max_keys)
-        
+
         return _parse_list_response(response)
 
     @gen.coroutine
@@ -735,7 +740,8 @@ def _list_keys(context, key_prefix, delimeter):
             for item in response.Contents:
                 key = item.Contents.Key
                 last_modified_str = item.Contents.LastModified
-                last_modified = datetime.datetime.strptime(last_modified_str, "%Y-%m-%dT%H:%M:%S.%fZ")
+                last_modified = datetime.datetime.strptime(
+                    last_modified_str, "%Y-%m-%dT%H:%M:%S.%fZ")
                 keys.append((key, last_modified))
         if 'CommonPrefixes' in response:
             # Prefixes end in '/', which we strip off
@@ -759,6 +765,7 @@ def _list_keys(context, key_prefix, delimeter):
 def _run_sync_in_new_thread(func):
     result = None
     exception = None
+
     def _func():
         nonlocal result
         nonlocal exception
@@ -777,6 +784,7 @@ def _run_sync_in_new_thread(func):
     else:
         return result
 
+
 GETTERS = {
     ('notebook', 'json'): _get_notebook,
     ('file', 'text'): _get_file_text,
@@ -794,12 +802,8 @@ SAVERS = {
 
 # 'endpoint_url': AwsCreds.endpoint_url,
 
-s3_client = boto3.client('s3',
-            aws_access_key_id = AwsCreds.access_key_id,
-            aws_secret_access_key = AwsCreds.secret_access_key,
-            region_name = 'us-east-1',
-            endpoint_url = Context.endpoint_url
-            )
+s3_client = boto3.client('s3', aws_access_key_id=AwsCreds.access_key_id,
+                         aws_secret_access_key=AwsCreds.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
 
 
 def _head_object(bucket, key):
@@ -808,7 +812,7 @@ def _head_object(bucket, key):
         return True
     else:
         return False
-    
+
 
 def _put_object(bucket, body, object_name):
 
@@ -826,18 +830,19 @@ def _list_buckets():
     # Retrieve the list of existing buckets
     return s3_client.list_buckets()
 
+
 def _copy_object(bucket, source_file, destination_file):
-    return s3_client.copy_object(Bucket=bucket,CopySource=source_file, Key=destination_file)
+    return s3_client.copy_object(Bucket=bucket, CopySource=source_file, Key=destination_file)
+
 
 def _delete_object(bucket, file_name):
     return s3_client.delete_object(Bucket=bucket, Key=file_name)
 
+
 def _list_objects(bucket, prefix, delimiter, max_keys, token):
     return s3_client.list_objects_v2(
-            Bucket=bucket,
-            Delimiter=delimiter,
-            MaxKeys=max_keys,
-            Prefix=prefix,
-            ContinuationToken=token)
-
-
+        Bucket=bucket,
+        Delimiter=delimiter,
+        MaxKeys=max_keys,
+        Prefix=prefix,
+        ContinuationToken=token)
